@@ -520,7 +520,8 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 lines = []
                 for line in iter(process.stdout.readline, b''):
                     lines.append(line)
-                    stdout.append(line)
+                    if not self.trash_output:
+                        stdout.append(line)
                     if time.time() - start > 30:
                         self.post_message(queue, ''.join(lines))
                         lines = []
@@ -532,9 +533,6 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 # stdout we don't know the difference. To keep the return dict
                 # similar there is an empty stderr. We can use the return code
                 # to determine if there was an error.
-                if self.trash_output:
-                    stdout = []
-                    stderr = ""
                 return {"stdout": "".join(stdout), "returncode": returncode,
                         "stderr": ""}
 
@@ -542,6 +540,9 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 *command, cwd=self.work_dir,
                 env_variables=env_variables,
                 log_errors=processutils.LogErrors.ALL)
+            if self.trash_output:
+                stdout = ""
+                stderr = ""
             return {"stderr": stderr, "stdout": stdout,
                     "log_path": os.path.join(self.work_dir, 'ansible.log')}
         finally:
