@@ -102,6 +102,7 @@ PASSWORD_PARAMETER_NAMES = (
     'NovaPassword',
     'NovajoinPassword',
     'MigrationSshKey',
+    'OctaviaServerCertsKeyPassphrase',
     'OctaviaCaKeyPassphrase',
     'OctaviaHeartbeatKey',
     'OctaviaPassword',
@@ -167,3 +168,9 @@ TRIPLEO_DEPLOYMENT_RESOURCE = 'TripleODeployment'
 HOST_NETWORK = 'ctlplane'
 
 EXTERNAL_TASKS = ['external_deploy_tasks']
+
+ANSIBLE_ERRORS_FILE = 'ansible-errors.json'
+
+DEPLOYMENT_STATUS_FILE = 'deployment_status.yaml'
+
+MISTRAL_WORK_DIR = '/var/lib/mistral'
