@@ -259,9 +259,10 @@ class Config(object):
                 deployment_stack = self.client.stacks.get(
                     deployment_stack_id, resolve_outputs=False)
                 parent_stack = deployment_stack.parent
+                grandparent_stack = self.client.stacks.get(
+                    parent_stack, resolve_outputs=False).parent
                 resources = self.client.resources.list(
-                    name,
-                    nested_depth=constants.NESTED_DEPTH,
+                    grandparent_stack,
                     filters=dict(physical_resource_id=parent_stack))
                 if not resources:
                     message = "The deployment resource grandparent name could" \
@@ -370,6 +371,12 @@ class Config(object):
                     pre_deployments=deployments['pre_deployments'],
                     post_deployments=deployments['post_deployments']))
 
+        shutil.copyfile(
+            os.path.join(templates_path, 'deployments.yaml'),
+            os.path.join(tmp_path, 'deployments.yaml'))
+
+        # Also copy deployments.yaml to the role dir for temporary backwards
+        # compatibility until https://review.openstack.org/574474 merges.
         for role_name, role in six.iteritems(role_data):
             role_path = os.path.join(tmp_path, role_name)
 
